@@ -189,6 +189,10 @@ void SendJob::Private::doTraditionalTransport()
     message->removeHeader( "X-KMail-Identity" );
     needAssemble = true;
   }
+  if ( message->hasHeader( "X-KMail-Dictionary") ) {
+      message->removeHeader( "X-KMail-Dictionary" );
+      needAssemble = true;
+  }
   if(needAssemble) {
     message->assemble();
   }
