@@ -264,8 +264,12 @@ void SerializerPluginKAlarm::reportDifference(AbstractDifferencesReporter* repor
         reporter->addProperty(AbstractDifferencesReporter::ConflictMode, KAEventFormatter::label(id), mValueL.value(id), mValueR.value(id));
 }
 
+QString SerializerPluginKAlarm::extractGid(const Item& item) const
+{
+    return item.hasPayload<KAEvent>() ? item.payload<KAEvent>().id() : QString();
+}
+
 Q_EXPORT_PLUGIN2(akonadi_serializer_kalarm, SerializerPluginKAlarm)
 
-#include "akonadi_serializer_kalarm.moc"
 
 // vim: et sw=4:
