@@ -52,7 +52,8 @@ public:
     CapabilitiesTestError,
     IncompatibleServerError,
     NoAvailableSessionError,
-    CouldNotConnectError
+    CouldNotConnectError,
+    CancelledError
   };
 
   enum SessionTermination {
@@ -99,6 +100,7 @@ private slots:
   void onNamespacesTestDone( KJob *job );
 
   void onSessionStateChanged(KIMAP::Session::State newState, KIMAP::Session::State oldState);
+  void onSessionDestroyed(QObject*);
 
 private:
   void onConnectionLost();
