@@ -27,7 +27,6 @@
 #include <KUrl>
 
 #include <QDir>
-#include <QSettings>
 
 #include <akonadi/private/xdgbasedirs_p.h>
 #include <akonadi/agentmanager.h>
@@ -162,4 +161,3 @@ void Backup::create( const KUrl& filename )
     emit completed( true );
 }
 
-#include "backup.moc"
